uri property
A package: URI suitable for use directly with other systems if this
asset is under it's package's lib/ directory, else an asset: URI
suitable for use within build tools.
Implementation
late final Uri uri = _constructUri(this);
A package: URI suitable for use directly with other systems if this
asset is under it's package's lib/ directory, else an asset: URI
suitable for use within build tools.
late final Uri uri = _constructUri(this);