writeAsBytes method
Writes bytes to a binary file located at id.
Returns a Future that completes after writing the asset out.
- Throws a
PackageNotFoundExceptionifid.packageis not found. - Throws an
InvalidOutputExceptionif the output was not valid.
Implementation
@override
Future<void> writeAsBytes(AssetId id, List<int> bytes) {
_assetsWritten.add(id);
return _delegate.writeAsBytes(id, bytes);
}